@@ -1,6 +1,6 @@
 /*
  * 
- * $Id: field.c,v 1.29.8.8 2004/03/20 15:25:09 usu Exp $
+ * $Id: field.c,v 1.29.8.9 2005/07/21 08:47:54 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000-2004 Namazu Project All rights reserved.
@@ -122,7 +122,7 @@ nmz_isfield(const char *key)
         }
         key++;
     }
-    if (isalpha(*(key - 1)) && *key == ':' ) {
+    if (isalpha((unsigned char)*(key - 1)) && *key == ':' ) {
         return 1;
     }
     return 0;
