@@ -2,7 +2,7 @@
  * 
  * wakati.c -
  * 
- * $Id: wakati.c,v 1.26.8.3 2004/03/20 15:25:10 usu Exp $
+ * $Id: wakati.c,v 1.26.8.5 2005/07/21 08:47:54 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000,2001,2003 Namazu Project All rights reserved.
@@ -82,7 +82,7 @@ iskatakana(const char *chr)
     c = (uchar *)chr;
 
     if ((*c == 0xa5) &&
-	(*(c + 1) >= 0xa0) && (*(c + 1) <= 0xff))
+	(*(c + 1) >= 0xa0)) /* 0xa0 <= *(c + 1) <= 0xff */
     {
 	return 1;
     } else if ((*c == 0xa1) && (*(c + 1) == 0xbc)) { /* choon */ 
@@ -101,7 +101,7 @@ ishiragana(const char *chr)
     c = (uchar *)chr;
 
     if ((*c == 0xa4) &&
-	(*(c + 1) >= 0xa0) && (*(c + 1) <= 0xff))
+	(*(c + 1) >= 0xa0)) /* 0xa0 <= *(c + 1) <= 0xff */
     {
 	return 1;
     } else if ((*c == 0xa1) && (*(c + 1) == 0xbc)) { /* choon */ 
@@ -127,7 +127,7 @@ nmz_wakati(char *key)
 
     nmz_debug_printf("wakati original: [%s].\n", key);
 
-    for (i = 0; i < strlen(key); ) {
+    for (i = 0; i < (int)strlen(key); ) {
         type = detect_char_type(key + i);
 	if (nmz_iseuc(*(key + i))) {
 	    key_leng = 0;
