@@ -2,10 +2,10 @@
  * 
  * form.c -
  * 
- * $Id: form.c,v 1.60.4.10 2002/03/06 06:20:47 knok Exp $
+ * $Id: form.c,v 1.60.4.19 2005/11/10 21:48:41 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000 Namazu Project All rights reserved.
+ * Copyright (C) 2000-2005 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -96,7 +96,7 @@ cmp_element(const char *s1, const char *s2)
             }
             s2++;
         }
-        if (toupper(*s1) != toupper(*s2)) {
+        if (_nmz_toupper((unsigned char)*s1) != _nmz_toupper((unsigned char)*s2)) {
             break;
         }
     }
@@ -114,24 +114,65 @@ static enum nmz_stat
 replace_query_value(const char *p, const char *query)
 {
     if (cmp_element(p, (char *)"input type=\"text\" name=\"query\"") == 0) {
-	char *converted = nmz_codeconv_external(query);
+	char *converted = nmz_query_external(query);
+
 	if (converted == NULL) {
 	    die("%s", strerror(errno));
 	}
 
         for (; *p; p++)
             fputc(*p, stdout);
-        printf(" value=\"");
-
-        html_print(converted);  /* for treating <>&" chars in the query. */
-        printf("\"");
 
+        {
+            printf(" value=\"");
+            html_print(converted);  /* for treating <>&" chars in the query. */
+            printf("\"");
+        }
 	free(converted);
         return SUCCESS;
     }
     return FAILURE;
 }
 
+char *
+nmz_query_external(const char *query)
+{
+    char *query_external;
+    char *alloc;
+    char *pos, *p;
+
+    alloc = strdup(query);
+    if (alloc == NULL) { /* */
+        nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
+        return NULL;
+    }
+
+    nmz_codeconv_internal(alloc);
+
+    p = alloc;
+    while(*p == '\t') {
+        p++;
+    }
+    pos = p;
+
+    /* tr/\x01-\x1f\x7f/ /; # Remove control char. */
+    while(*p != '\0') {
+        if ((*p >= 0x01 && *p <= 0x1f) || *p == 0x7f) {
+            *p = ' ';
+        }
+        p++;
+    }
+
+    query_external = nmz_codeconv_external(pos);
+    free(alloc);
+    if (query_external == NULL) {
+        nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
+        return NULL;
+    }
+
+    return query_external;
+}
+
 /*
  * Delete string (case insensitive)
  */
@@ -171,7 +212,6 @@ get_value(const char *s, char *value)
 static void 
 get_select_name(const char *s, char *value)
 {
-    *value = '\0';
     for (; *s; s++) {
         if (cmp_element(s, (char *)"select name=\"") == 0) {
             s = (char *)strchr(s, '"') + 1;
@@ -180,6 +220,9 @@ get_select_name(const char *s, char *value)
             }
             *value = '\0';
             return;
+        } else if (cmp_element(s, (char *)"/select") == 0) {
+            *value = '\0';
+            return;
         }
     }
 }
@@ -187,10 +230,10 @@ get_select_name(const char *s, char *value)
 static enum nmz_stat
 select_option(char *s, const char *name, const char *subquery)
 {
-    char value[BUFSIZE];
+    char value[BUFSIZE] = "";
 
     if (cmp_element(s, (char *)"option") == 0) {
-	if(strcmp(nmz_getenv("QUERY_STRING"), "")) {
+	if (strcmp(nmz_getenv("QUERY_STRING"), "")) {
             delete_str(s, (char *)"selected ");
 	}
         fputs(s, stdout);
@@ -219,7 +262,7 @@ select_option(char *s, const char *name, const char *subquery)
 	    {
 		char *p;
 		int n, order = DESCENDING;
-		char field[BUFSIZE];
+		char field[BUFSIZE] = "";
 
 		p = value + strlen("field:");
 		n = strspn(p, FIELD_SAFE_CHARS);
@@ -269,20 +312,20 @@ select_option(char *s, const char *name, const char *subquery)
 static enum nmz_stat
 check_checkbox(char *str)
 {
-    char value[BUFSIZE];
+    char value[BUFSIZE] = "";
     int i;
 
     if (cmp_element(str, "input type=\"checkbox\" name=\"idxname\"") == 0) {
         char *pp;
         int db_count, searched;
 
-	if(strcmp(nmz_getenv("QUERY_STRING"), "")) {
+	if (strcmp(nmz_getenv("QUERY_STRING"), "")) {
             delete_str(str, (char *)"checked");
 	}
         fputs(str, stdout);
         get_value(str, value);
         for (pp = value, db_count = searched = 0 ; *pp ;db_count++) {
-            char name[BUFSIZE], *x;
+            char name[BUFSIZE] = "", *x;
             if ((x = (char *)strchr(pp, (int)','))) {
                 *x = '\0';
                 strncpy(name, pp, BUFSIZE - 1);
@@ -316,7 +359,7 @@ static void
 handle_tag(const char *start, const char *end, const char *query, 
                char *select_name, const char *subquery)
 {
-    char tmp[BUFSIZE];
+    char tmp[BUFSIZE] = "";
     int l;
 
     l = end - start + 1;
@@ -339,7 +382,7 @@ handle_tag(const char *start, const char *end, const char *query,
 static char *
 read_headfoot(const char *fname) 
 {
-    char *buf, *p, tmpfname[BUFSIZE], suffix[BUFSIZE];
+    char *buf, *p, tmpfname[BUFSIZE] = "", suffix[BUFSIZE] = "";
     char *script_name;
     char *document_name;
 
@@ -447,11 +490,13 @@ print_headfoot(const char * fname, const char * query, const char *subquery)
         if (f == 0 && *p == '<') {
             if (nmz_strprefixcasecmp(p, "</title>") == 0) {
 		if (*query != '\0') {
-		    char *converted = nmz_codeconv_external(query);
-		    printf(": &lt;");
-		    html_print(converted);
-		    printf("&gt;");
-		    free(converted);
+		    char *converted = nmz_query_external(query);
+                    if (converted) {
+                        printf(": &lt;");
+                        html_print(converted);
+                        printf("&gt;");
+                        free(converted);
+                    }
 		}
 		printf("</title>\n");
                 p = (char *)strchr(p, '>');
@@ -480,8 +525,13 @@ print_headfoot(const char * fname, const char * query, const char *subquery)
 	     */
             q = (char *)strchr(p, (int)'>');
             fputs("<", stdout);
-            handle_tag(p + 1, q - 1, query, name, subquery);
-            fputs(">", stdout);
+	    if (*(q-1) != '/') {
+		handle_tag(p + 1, q - 1, query, name, subquery);
+		fputs(">", stdout);
+	    } else {            /* for XHTML */
+		handle_tag(p + 1, q - 2, query, name, subquery);
+		fputs("/>", stdout);
+	    }
             p = q;
         } else {
             if ((strncmp(p, "\033$", 2) == 0)
@@ -499,8 +549,3 @@ print_headfoot(const char * fname, const char * query, const char *subquery)
     }
     free(buf);
 }
-
-
-
-
-
