@@ -37,5 +37,7 @@ extern char *get_templatesuffix ( void );
 extern void html_print ( const char *str );
 extern void print ( const char *str );
 extern void die(const char *fmt, ...);
+extern void puts_entitize( const char *str );
+extern void putc_entitize( int c );
 
 #endif /* _OUTPUT_H */
